.. _libdoc_graph_utils:

==========================================================
:mod:`utils` -- Utilities functions operating on the graph
==========================================================

.. testsetup:: *

   from aesara.graph.utils import *

---------
Reference
---------

.. automodule:: aesara.graph.utils
   :platform: Unix, Windows
   :synopsis: Utilities functions operating on the graph
   :members:
.. moduleauthor:: LISA
